@@ -13,6 +13,10 @@ class AlohaInput(TextInput):
     
     template_name='djaloha/alohainput.html'
     
+    def __init__(self, *args, **kwargs):
+        self._text_color_plugin = kwargs.pop('text_color_plugin', True)
+        super(AlohaInput, self).__init__(*args, **kwargs)
+    
     def _get_media(self):
         """
         return code for inserting required js and css files
@@ -28,7 +32,11 @@ class AlohaInput(TextInput):
         }
         
         js = (
-            "aloha/aloha.js",
+            "js/_lib/jquery.cookie.js",
+            "aloha/sizzle.js",
+            "aloha/ext-jquery-adapter.js",
+            "aloha/ext-all.js",
+            "aloha/aloha-nodeps.js",
             "aloha/plugins/com.gentics.aloha.plugins.Format/plugin.js",
             "aloha/plugins/com.gentics.aloha.plugins.List/plugin.js",
             "aloha/plugins/com.gentics.aloha.plugins.HighlightEditables/plugin.js",
@@ -38,10 +46,13 @@ class AlohaInput(TextInput):
             "aloha/plugins/com.gentics.aloha.plugins.Paste/plugin.js",
             "aloha/plugins/com.gentics.aloha.plugins.Paste/wordpastehandler.js",
             "aloha/plugins/at.tapo.aloha.plugins.Image/plugin.js",
-            "aloha/plugins/TextColor/plugin.js",
-            reverse('aloha_init'),
         )
         
+        if self._text_color_plugin:
+            js = js + ("aloha/plugins/TextColor/plugin.js",)
+
+        js = js + (reverse('aloha_init'), )
+        
         return Media(css=css, js=js)
     
     media = property(_get_media)
